" Vim syntax file
" Language:	Install Shieled script (rul)
" Maintainer:	ken_t@st.rim.or.jp
" Heavily based on c.vim by Bram Moolenaar
" Last change:	1998 Jun 10

" Remove any old syntax stuff hanging around
syn clear

" A bunch of useful Install Shield keywords
syn keyword cStatement		goto return call exit
syn keyword cLabel		case default
syn keyword cConditional	if else elseif endif switch endswitch
syn keyword cRepeat		while endwhile for endfor repeat until
syn keyword cBlock		begin end
syn keyword cPreProc		declare prototype function program


syn keyword cTodo contained	TODO FIXME XXX

" String and Character constants
" Highlight special characters (those which have a backslash) differently
syn match cSpecial contained	"\\[0-7][0-7][0-7]\=\|\\."
syn region cString		start=+"+ skip=+\\\\\|\\"+ end=+"+ contains=cSpecial
syn match	cCharacter		"'[^\\]'"
syn match	cSpecialCharacter	"'\\.'"
syn match	cSpecialCharacter	"'\\[0-7][0-7]'"
syn match	cSpecialCharacter	"'\\[0-7][0-7][0-7]'"

" Install Shield Constants
syn keyword	cIsConstants	AFTER APPEND BACK BEFORE CANCEL COMMAND CONTINUE
syn keyword	cIsConstants	DISABLE ENABLE EXCLUSIVE EXISTS FAILIFEXISTS
syn keyword	cIsConstants	FALSE FULL NEXT NO NONEXCLUSIVE NOSET OFF ON
syn keyword	cIsConstants	REPLACE REPLACE_ITEM RESET RESTART SET TRUE YES

" Install Shield Variables
syn keyword	cIsVariables	CMDLINE COMMONFILES ERRORFILENAME FOLDER_DESKTOP
syn keyword	cIsVariables	FOLDER_STARTMENU FOLDER_STARTUP INFOFILENAME
syn keyword	cIsVariables	ISRES ISUSER ISVERSION PROGRAMFILES SRCDIR
syn keyword	cIsVariables	SRCDISK SUPPORTDIR TARGETDIR TARGETDISK WINDIR
syn keyword	cIsVariables	WINDISK WINSYSDIR WINSYSDISK

" Install Shield Function's
syn keyword	cIsFunctions	AddFolderIcon AddProfString AddressNumber AddressString AddressStruct AskDestPath AskOptions AskPath AskText AskYesNo
syn keyword	cIsFunctions	BatchAdd BatchDeleteEx BatchFileLoad BatchFileSave BatchFind BatchGetFileName BatchMoveEx BatchSetFileName
syn keyword	cIsFunctions	ChangeDirectory CheckRequirements ComponentAddItem ComponentDialog ComponentIsItemSelected ComponentListItems ComponentSetItemInfo CompressAdd CompressDel CompressEnum ConfigAdd ConfigDelete ConfigFileLoad ConfigFileSave ConfigFind ConfigGetFileName ConfigGetInt ConfigMove ConfigSetFileName ConfigSetInt CopyBytes CopyFile CreateDir CreateFile CreateProgGroupEx CreateProgramFolder CtrlGetMLEText CtrlGetMultCurSel CtrlGetState CtrlSetList CtrlSetMLEText
syn keyword	cIsFunctions	DeleteDir DeleteFile DeleteFolderIcon DialogSetInfo Disable
syn keyword	cIsFunctions	Enable EnterDisk EzBatchAddPath EzBatchAddString EzBatchReplace EzConfigAddDriver EzConfigAddString EzConfigGetValue EzConfigSetValue EzDefineDialog
syn keyword	cIsFunctions	FileCompare FileDeleteLine FileGrep FileInsertLIne FileSetBeginDefine FileSetEndDefine FileSetPerform FileSetPerformEz FileSetReset FindAllDirs FindAllFiles FindFile FindWindow
syn keyword	cIsFunctions	GetByte GetDir GetDisk GetDiskSpace GetExtents GetFileInfo GetGroupNameList GetLine GetProfInt GetProfString GetValidDrivesList
syn keyword	cIsFunctions	InstallationInfo Is
syn keyword	cIsFunctions	LaunchApp LaunchAppAndWait ListAddItem ListAddString ListCount ListCreate ListCurrentItem ListCurrentString ListDeleteItem ListDeleteString ListDestroy ListFindItem ListFindString ListGetFirstItem ListGetFirstString ListGetNextItem ListGetNextString ListReadFromFile ListSetCurrentItem ListSetCurrentString ListSetIndex ListWriteToFile LongPathToQuote LongPathToShortPath
syn keyword	cIsFunctions	MessageBox MoveTo
syn keyword	cIsFunctions	NumToStr
syn keyword	cIsFunctions	OpenFile OpenFileMode
syn keyword	cIsFunctions	ParsePath PathAdd PathDelete PathFind PathGet PathMove PathSet PlaceBitmap PlaceWindow
syn keyword	cIsFunctions	ReadBytes BebootDialog RegDBCreateKeyEx RegDBDeleteKey RegDBGetAppInfo RegDBGetKeyValueEx RegDBKeyExist RegDBSetAppInfo RegDBSetDefaultRoot RegDBSetItem RegDBSetKeyValueEx ReloadProgGroup RenameFile ReplaceProfString ReplaceProgItem
syn keyword	cIsFunctions	SdAskDestPath AdAskOptions SdAskOptionsList SdBitmap SdComponentDialog SdComponenetDialog2 SdComponetDialogAdv SdComponentMult SdConfirmNewDir SdConfirmRegistration SdDisplayTopics SdOptionsButtons SdProductName SdRegisterUser SdRegisterUserEx SdSelectFolder SdShowDlgEdit1 SdShowDlgEdit2 SdShowDlgEdit3 SdShowFileMods SdShowMsg SdWelecom SeekBytes SelectDir SelectFolder SendMessage SetByte SetColor SetDialogTitle SetFileInfo SetFont SetStatusWindow SetTitle SetupFileTransfer SetupScreen SetUpType SizeWindow SprintfBox StatusUpdate StrCompare StrFind StrGetTokens StrLengh StrRemoveLastSlash StrSub StrToLower StrToNum StrToUpper
syn keyword	cIsFunctions	UnUseDll
syn keyword	cIsFunctions	VerCompare VerFindFileVersion VerGetFileVersion VerSearchAndUpdateFile VerUpdateFile
syn keyword	cIsFunctions	Welcome WriteBytes WriteLine WriteProfString
syn keyword	cIsFunctions	XCopyFilev XCopyFile

"catch errors caused by wrong parenthesis
syn region	cParen		transparent start='(' end=')' contains=ALLBUT,cParenError,cIncluded,cSpecial,cTodo,cUserLabel
syn match	cParenError	")"
syn match	cInParen	contained	"[{}]"

"integer number, or floating point number without a dot and with "f".
syn case	ignore
syn match	cNumber		"\<[0-9]\+\(u\=l\=\|lu\|f\)\>"
"hex number
syn match	cNumber		"\<0x[0-9a-f]\+\(u\=l\=\|lu\)\>"
"syn match cIdentifier	"\<[a-z_][a-z0-9_]*\>"
syn case match
" flag an octal number with wrong digits
syn match	cOctalError	"\<0[0-7]*[89]"

if exists("c_comment_strings")
  " A comment can contain cString, cCharacter and cNumber.
  " But a "*/" inside a cString in a cComment DOES end the comment!  So we
  " need to use a special type of cString: cCommentString, which also ends on
  " "*/", and sees a "*" at the start of the line as comment again.
  " Unfortunately this doesn't very well work for // type of comments :-(
  syntax match	cCommentSkip	contained "^\s*\*\($\|\s\+\)"
  syntax region	cCommentString	contained start=+"+ skip=+\\\\\|\\"+ end=+"+ end=+\*/+me=s-1 contains=cSpecial,cCommentSkip
  syntax region	cComment2String	contained start=+"+ skip=+\\\\\|\\"+ end=+"+ end="$" contains=cSpecial
  syntax region	cComment	start="/\*" end="\*/" contains=cTodo,cCommentString,cCharacter,cNumber
  syntax match	cComment	"//.*" contains=cTodo,cComment2String,cCharacter,cNumber
else
  syn region	cComment	start="/\*" end="\*/" contains=cTodo
  syn match	cComment	"//.*" contains=cTodo
endif
syntax match	cCommentError	"\*/"

syn keyword	cOperator	BYREF
syn keyword	cType		BOOL CHAR HWND INT LIST LONG NUMBER POINTER STRING SHORT

syn region	cPreCondit	start="^\s*#\s*\(if\>\|ifdef\>\|ifndef\>\|elif\>\|else\>\|endif\>\)" skip="\\$" end="$" contains=cComment,cString,cCharacter,cNumber,cCommentError
syn region	cIncluded	contained start=+"+ skip=+\\\\\|\\"+ end=+"+
syn match	cIncluded	contained "<[^>]*>"
syn match	cInclude	"^\s*#\s*include\>\s*["<]" contains=cIncluded
"syn match cLineSkip	"\\$"
syn region	cDefine		start="^\s*#\s*\(define\>\|undef\>\)" skip="\\$" end="$" contains=ALLBUT,cPreCondit,cIncluded,cInclude,cDefine,cInParen

" Highlight User Labels
syn region	cMulti		transparent start='?' end=':' contains=ALLBUT,cIncluded,cSpecial,cTodo,cUserLabel
" Avoid matching foo::bar() in C++ by requiring that the next char is not ':'
syn match	cUserLabel	"^\s*\I\i*\s*:$"
syn match	cUserLabel	";\s*\I\i*\s*:$"ms=s+1
syn match	cUserLabel	"^\s*\I\i*\s*:[^:]"me=e-1
syn match	cUserLabel	";\s*\I\i*\s*:[^:]"ms=s+1,me=e-1

syn sync ccomment cComment minlines=10

if !exists("did_is_syntax_inits")
  let did_is_syntax_inits = 1
  " The default methods for highlighting.  Can be overridden later
  hi link cLabel		Label
  hi link cUserLabel		Label
  hi link cConditional		Conditional
  hi link cRepeat		Repeat
  hi link cBlock		cRepeat
  hi link cCharacter		Character
  hi link cSpecialCharacter	cSpecial
  hi link cNumber		Number
  hi link cOctalError		cError
  hi link cParenError		cError
  hi link cInParen		cError
  hi link cCommentError		cError
  hi link cOperator		Operator
  hi link cInclude		Include
  hi link cDefine		Macro
  hi link cIncluded		cString
  hi link cPreProc		PreProc
  hi link cError		Error
  hi link cStatement		Statement
  hi link cPreCondit		PreCondit
  hi link cType			Type
  hi link cCommentError		cError
  hi link cCommentString	cString
  hi link cComment2String	cString
  hi link cCommentSkip		cComment
  hi link cString		String
  hi link cComment		Comment
  hi link cSpecial		SpecialChar
  hi link cIsConstants		cConstants
  hi link cIsVariables		cVariables
  hi link cIsFunctions		cFunctions
  hi link cTodo			Todo
  "hi link cIdentifier		Identifier
  hi cConstants			ctermfg=darkgrey ctermbg=white guifg=darkgrey guibg=white
  hi cVariables			ctermfg=magenta ctermbg=white guifg=magenta guibg=white
  hi cFunctions			term=bold ctermbg=1 guifg=Red
endif

let b:current_syntax = "c"

" vim: ts=8
